@@ -1,7 +1,7 @@
 package Bencher;
 
-our $DATE = '2016-01-22'; # DATE
-our $VERSION = '0.34'; # VERSION
+our $DATE = '2016-02-18'; # DATE
+our $VERSION = '0.35'; # VERSION
 
 use 5.010001;
 use strict;
@@ -900,14 +900,17 @@ $SPEC{format_result} = {
 sub format_result {
     require POSIX;
 
-    my ($envres, $formatters) = @_;
+    my ($envres, $formatters, $opts) = @_;
+
+    $opts //= {};
 
     $formatters //= [
-        'Sort',
+        ['Sort', {by=>$opts->{sort}}],
         'ScaleTime',
         'ScaleRate',
-        'RoundNumbers',
         ($envres->[3]{'func.module_startup'} ? ('ModuleStartup') : ()),
+        'AddVsSlowestField',
+        'RoundNumbers',
         'DeleteConstantFields',
         'DeleteNotesFieldIfEmpty',
         'DeleteSeqField',
@@ -951,6 +954,7 @@ $SPEC{bencher} = {
     args_rels => {
         # XXX precision & precision_limit is only relevant when action=bench
         # XXX note is only relevant when action=bench
+        # XXX sort is only relevant when action=bench and format=text
     },
     args => {
         scenario_file => {
@@ -1007,7 +1011,7 @@ _
 This setting overrides `default_precision` property in the scenario.
 
 _
-            schema => ['float*', between=>[0,1]],
+            schema => ['float*', min=>0],
         },
         precision_limit => {
             summary => 'Set maximum (=smallest number) precision',
@@ -1326,6 +1330,11 @@ warning to STDERR and continue.
 _
         },
 
+        sort => {
+            schema => ['array*', of=>'str*', min_len=>1],
+            default => ['-time'],
+        },
+
         note => {
             summary => 'Put additional note in the result',
             schema => 'str*',
@@ -1682,7 +1691,8 @@ sub bencher {
             $envres->[3]{'func.time_start'} = Time::HiRes::time();
         }
 
-        my $precision = $args{precision} // $parsed->{default_precision} // 0;
+        my $precision = $args{precision} //
+            $parsed->{precision} // $parsed->{default_precision} // 0;
         if (defined($args{precision_limit}) && $precision < $args{precision_limit}) {
             $precision = $args{precision_limit};
         }
@@ -1745,7 +1755,7 @@ sub bencher {
 
             $envres = [
                 200, "OK",
-                format_result($envres),
+                format_result($envres, undef, {sort=>$args{sort}}),
                 {
                     "cmdline.skip_format" => 1,
                 },
@@ -1814,7 +1824,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 0.34 of Bencher (from Perl distribution Bencher), released on 2016-01-22.
+This document describes version 0.35 of Bencher (from Perl distribution Bencher), released on 2016-02-18.
 
 =head1 SYNOPSIS
 
@@ -2300,6 +2310,8 @@ Will try to load module C<< Bencher::Scenario::E<lt>NAMEE<gt> >> and expect to f
 variable in the module called C<$scenario> which should be a hashref containing
 the scenario specification.
 
+=item * B<sort> => I<array[str]> (default: ["-time"])
+
 =back
 
 Returns an enveloped result (an array).
