@@ -1,7 +1,7 @@
 package Bencher::Formatter::Sort;
 
-our $DATE = '2016-01-22'; # DATE
-our $VERSION = '0.34'; # VERSION
+our $DATE = '2016-02-18'; # DATE
+our $VERSION = '0.35'; # VERSION
 
 use 5.010001;
 use strict;
@@ -16,8 +16,21 @@ with 'Bencher::Role::ResultMunger';
 sub munge_result {
     my ($self, $envres) = @_;
 
+    $self->{by} //= ['-time'];
+
     # sort by default from slowest to fastest
-    $envres->[2] = [sort {$b->{time} <=> $a->{time}} @{$envres->[2]}];
+    $envres->[2] = [sort {
+        for my $by0 (@{ $self->{by} }) {
+            my ($desc, $by) = $by0 =~ /^(-?)(.+)/;
+            return 0 unless defined($a->{$by}) && defined($b->{$by});
+            my $numeric = $by =~ /time|time|errors|samples/ ? 1:0; # XXX ad-hoc
+            my $res = ($desc ? -1:1) * ($numeric ?
+                                            $a->{$by} <=> $b->{$by} :
+                                            $a->{$by} cmp $b->{$by});
+            return $res if $res;
+        }
+        0;
+    } @{$envres->[2]}];
 }
 
 1;
@@ -35,7 +48,7 @@ Bencher::Formatter::Sort - Sort rows
 
 =head1 VERSION
 
-This document describes version 0.34 of Bencher::Formatter::Sort (from Perl distribution Bencher), released on 2016-01-22.
+This document describes version 0.35 of Bencher::Formatter::Sort (from Perl distribution Bencher), released on 2016-02-18.
 
 =head1 DESCRIPTION
 
@@ -44,6 +57,13 @@ C<time> value).
 
 =for Pod::Coverage .*
 
+=head1 OPTIONS
+
+=head2 by => array of str (default: ["-time"])
+
+Customize sort orders. One or more field names (field name can be prefixed with
+C<-> (dash) to mean descending order).
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher>.
